==> kubernetes-model-admissionregistration-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1/WebhookClientConfigFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface WebhookClientConfigFluent<A extends io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getCaBundle();
  public A withCaBundle(java.lang.String caBundle);
  public java.lang.Boolean hasCaBundle();
  
  /**
   * Method is deprecated. use withCaBundle instead.
   */
  @java.lang.Deprecated
  public A withNewCaBundle(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildService instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.ServiceReference getService();
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.ServiceReference buildService();
  public A withService(io.fabric8.kubernetes.api.model.admissionregistration.v1.ServiceReference service);
  public java.lang.Boolean hasService();
  public A withNewService(java.lang.String name,java.lang.String namespace,java.lang.String path,java.lang.Integer port);
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent.ServiceNested<A> withNewService();
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent.ServiceNested<A> withNewServiceLike(io.fabric8.kubernetes.api.model.admissionregistration.v1.ServiceReference item);
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent.ServiceNested<A> editService();
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent.ServiceNested<A> editOrNewService();
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent.ServiceNested<A> editOrNewServiceLike(io.fabric8.kubernetes.api.model.admissionregistration.v1.ServiceReference item);
  public java.lang.String getUrl();
  public A withUrl(java.lang.String url);
  public java.lang.Boolean hasUrl();
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0);
  public interface ServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admissionregistration.v1.ServiceReferenceFluent<io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent.ServiceNested<N>>{
    public N and();
    public N endService();
    
  }
  
}

==> kubernetes-model-admissionregistration-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1/WebhookClientConfigFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface WebhookClientConfigFluent<A extends io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getCaBundle();
  public A withCaBundle(java.lang.String caBundle);
  public java.lang.Boolean hasCaBundle();
  
  /**
   * Method is deprecated. use withCaBundle instead.
   */
  @java.lang.Deprecated
  public A withNewCaBundle(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildService instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.ServiceReference getService();
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.ServiceReference buildService();
  public A withService(io.fabric8.kubernetes.api.model.admissionregistration.v1.ServiceReference service);
  public java.lang.Boolean hasService();
  public A withNewService(java.lang.String name,java.lang.String namespace,java.lang.String path,java.lang.Integer port);
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent.ServiceNested<A> withNewService();
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent.ServiceNested<A> withNewServiceLike(io.fabric8.kubernetes.api.model.admissionregistration.v1.ServiceReference item);
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent.ServiceNested<A> editService();
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent.ServiceNested<A> editOrNewService();
  public io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent.ServiceNested<A> editOrNewServiceLike(io.fabric8.kubernetes.api.model.admissionregistration.v1.ServiceReference item);
  public java.lang.String getUrl();
  public A withUrl(java.lang.String url);
  public java.lang.Boolean hasUrl();
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admissionregistration.v1.ServiceReferenceFluent<io.fabric8.kubernetes.api.model.admissionregistration.v1.WebhookClientConfigFluent.ServiceNested<N>>{
    public N and();
    public N endService();
    
  }
  
}
